m4_screw_radius = 4.826/2;
m4_hole_radius = m4_screw_radius * 1.20; 

back_slot_height = case_height - 13;
lid_mount_height = 4;
lid_mount_dim = m4_screw_radius *2 * 2;

rail_width = 20;
slot_width = 6.15;
part_thickness = 1.5;

switch_body_width = 11;
switch_connector_width = 5;
switch_roller_width = 16.25 - switch_body_width;
switch_height = 20;

switch_hole_dia = 2.5 * 1.175  ; //m2 screw dia with margin
switch_hole_spacing = 9.5;

switch_hole_offset_from_bottom = 3;
switch_hole_offset_from_back = 1.5;
switch_buffer = 2;

// 2019-10-05: value was previously 4.6, but I bought shorter screws
m4_screw_addl_thickness = 2.6;

module rail_tab(){
  difference(){
    union(){
      cube([rail_width, rail_width, part_thickness]);
      translate([rail_width/2, rail_width/2,0]){
        cylinder(r1 = m4_hole_radius * 3,r2 = m4_hole_radius + 2.1, h = m4_screw_addl_thickness);
      }
    }
    translate([rail_width/2, rail_width/2,-1]){
      cylinder(r = m4_hole_radius, h = part_thickness * 4, $fn = 15);
    }
  }
  
}

// From the bed overhang, remove the switch margin to make
// sure the switch closes;
switch_margin = 4.5;
// 2019-10-05: value was previously 17 - switch_margin, but this gave up almost 6.5mm of travel
bed_overhang = 21.1 - switch_margin;
bed_thickness = 15.0;

//From the bed height, subtract out the switch height
// and add 1/2 the bed thickness so the roller hits in the center
bed_height = 42.5 - (switch_height) + bed_thickness/2; 

reinforcement_dim = sqrt(pow(bed_overhang + switch_roller_width + switch_body_width,2) + pow(bed_height,2)) * 0.88;
reinforcement_angle = 180 - atan(bed_height/(bed_overhang + switch_body_width));

translate([0,0,part_thickness]){
  translate([part_thickness,part_thickness,0]){
    rotate([90,0,0]){
      rail_tab();
    }
  }

  translate([part_thickness ,part_thickness,0]){
    rotate([0,-90,0]){
      rail_tab();
    }
  }
  
  translate([0,part_thickness / 2,0]){
    rotate([0,-90,reinforcement_angle]){
      linear_extrude(height = part_thickness){
        polygon([
        [0,0],
        [rail_width, 0],
        [0, reinforcement_dim]
        ]);
      }
    }
  }
  
  translate([part_thickness, part_thickness,0]){
    difference(){
      cylinder(r = part_thickness * 1.3, h = rail_width, $fn = 22);
      translate([0,0,-2]){
        cube([part_thickness * 1.5,part_thickness * 1.5,rail_width  * 2]);
      }
    }
  }
}

color("grey") difference(){
    linear_extrude(height = part_thickness) polygon(points=[
  [part_thickness,part_thickness],
  [part_thickness + rail_width, part_thickness],
  [part_thickness + rail_width, 0],
  [-1*bed_height,-1*(bed_overhang + switch_body_width + switch_roller_width + switch_buffer)],
  [-1*(bed_height + switch_height),-1*(bed_overhang + switch_body_width + switch_roller_width + switch_buffer)],
  [-1*(bed_height + switch_height),-1*(bed_overhang + switch_roller_width)],
  [-1*bed_height,-1*(bed_overhang + switch_roller_width )],
  [0,part_thickness+ rail_width],
  [part_thickness, part_thickness+ rail_width]
  ]);
  union(){
    translate([-1*(bed_height + switch_hole_offset_from_bottom + switch_hole_dia/2),-1 * (bed_overhang + switch_body_width + switch_roller_width - switch_hole_offset_from_back),-2]){
      cylinder(r= switch_hole_dia/2, h= part_thickness * 3, $fn = 12);
      translate([-1 * (switch_hole_spacing),0,0]){
        cylinder(r= switch_hole_dia/2, h= part_thickness * 3 ,$fn = 12);
      }
    }
  }
}