m4_screw_radius = 4.826/2;
m4_hole_radius = m4_screw_radius * 1.20; 

back_slot_height = case_height - 13;
lid_mount_height = 4;
lid_mount_dim = m4_screw_radius *2 * 2;

rail_width = 20;
slot_width = 6.15;
part_thickness = 1.5;

switch_body_width = 11;
switch_connector_width = 5;
switch_roller_width = 16.25 - switch_body_width;
switch_height = 20;

switch_hole_dia = 2.5 * 1.175  ; //m2 screw dia with margin
switch_hole_spacing = 9.5;

switch_hole_offset_from_bottom = 3;
switch_hole_offset_from_back = 1.5;
switch_buffer = 2;

motor_offset_z = 5;
m4_screw_addl_thickness = 4.45;

module rail_tab(crown, tab_thickness){
  difference(){
    union(){
      cube([rail_width, rail_width, tab_thickness]);
      translate([rail_width/2, rail_width/2,0]){
        cylinder(r1 = m4_hole_radius * 3,r2 = m4_hole_radius + 2.1, h = crown*m4_screw_addl_thickness);
      }
    }
    translate([rail_width/2, rail_width/2,-1]){
      cylinder(r = m4_hole_radius, h = tab_thickness * 9, $fn = 15);
    }
  }
  
}


switch_margin = 2;
motor_offset = 33 - switch_height / 2; // Can subtract out half the switch height to save material. The roller can hit the switch anywhere
motor_offset_y = 11;

bed_thickness = 15.0;

//From the bed height, subtract out the switch height
// and add 1/2 the bed thickness so the roller hits in the center
bed_height = 42.5 - (switch_height) + bed_thickness/2; 

translate([0,0,part_thickness]){
  translate([part_thickness,part_thickness,0]){
    rotate([90,0,0]){
      rail_tab(1, part_thickness);
    }
  }

  translate([part_thickness ,part_thickness,0]){
    rotate([0,-90,0]){
      rail_tab(0,part_thickness);
    }
  }
  
  translate([part_thickness,part_thickness / 2,]){
    rotate([0,90,180]){
      difference(){
        linear_extrude(height = part_thickness){
          polygon([
          [0,0],
          [0,-1*(rail_width + part_thickness/2)],
          [rail_width/2, -1 *rail_width/2],
          [switch_body_width + switch_margin, 0],
          [switch_buffer + switch_body_width + switch_roller_width- motor_offset_y - switch_margin, motor_offset],          
          [switch_buffer + switch_body_width + switch_roller_width - motor_offset_y - switch_margin, motor_offset + switch_height],                   
          [switch_roller_width- motor_offset_y - switch_margin, motor_offset + switch_height],
          [switch_roller_width- motor_offset_y - switch_margin, motor_offset],
          ]);
        }
        
        translate([switch_roller_width + switch_body_width - motor_offset_y - switch_hole_offset_from_back,1 *(motor_offset + switch_hole_offset_from_bottom),-1]){          
          rotate([0,0,90]){
            translate([switch_hole_dia/2,switch_margin,0]){
              cylinder(r= switch_hole_dia/2, h = part_thickness *3, $fn = 21);
              translate([switch_hole_spacing,0,0]){
                cylinder(r= switch_hole_dia/2, h = part_thickness *3, $fn = 21);
              }
            }
          }
      }
      }
      

    }
  }
  
  translate([0,0,0]){
    cube([part_thickness,part_thickness,rail_width ]);
    
  }
}

color("grey") difference(){
    linear_extrude(height = part_thickness) polygon(points=[
  [part_thickness,part_thickness],
  [part_thickness + rail_width*0.9, part_thickness],
  [part_thickness + rail_width*0.9, 0],
  [part_thickness, -1*motor_offset * 0.95],
  
  
  
  ]);
  
}