m4_screw_radius = 4.826/2;
m4_hole_radius = m4_screw_radius * 1.20; 

rail_width = 20;
slot_width = 6.15;
part_thickness = 1.5;

switch_body_width = 10.4;
switch_connector_width = 5;
switch_roller_width = 17.1 - switch_body_width;
switch_height = 20;

switch_hole_dia = 2.5 * 1.177  ; //m2 screw dia with margin
switch_hole_spacing = 9.5;

switch_hole_offset_from_bottom = 3;
switch_hole_offset_from_back = 1.5;
switch_buffer = 2;
switch_hole_offset_from_top = 4.0; 
switch_hole_offset_from_front = 6.4; 

motor_offset_z = 5;
m4_screw_addl_thickness = 4.45;
switch_margin = 2;

z_carriage_lip_height = 10.00;
z_carriage_gap_dim = 79.0;
z_carriage_wall_thickness = 2.97;
z_carriage_lower_pocket_width = 12.9;
z_carriage_lower_pocket_height = z_carriage_lip_height - z_carriage_wall_thickness;
part_thickness = 1.33;

switch_offset_from_back = 10.75;

clearance_margin = 3.25;
overall_height = z_carriage_gap_dim + z_carriage_lip_height*2;

lower_clip_margin = 0.15;

locking_tab_offset_from_bottom = z_carriage_lip_height - z_carriage_lower_pocket_height;
cube([part_thickness, overall_height ,switch_offset_from_back - clearance_margin]);

translate([-1 * (z_carriage_wall_thickness + lower_clip_margin), z_carriage_lip_height,part_thickness]){
  cube([z_carriage_wall_thickness + lower_clip_margin, part_thickness, switch_offset_from_back - clearance_margin - part_thickness]);
}
translate([-1 * (z_carriage_wall_thickness + part_thickness + lower_clip_margin), locking_tab_offset_from_bottom + 1,part_thickness]){
  cube([part_thickness, z_carriage_lower_pocket_height + part_thickness - 1, switch_offset_from_back - clearance_margin - part_thickness]);
}

upper_locking_tab_width = 3.5;
upper_inner_locking_tab_depth = 0.7;
// subtracting 0.x below in translate so we don't get a strict interference fit
translate([-1 *upper_locking_tab_width,overall_height/2 - 0.15,0]){
  cube([upper_locking_tab_width, overall_height/ 2 - z_carriage_lip_height,part_thickness]);
  
  translate([upper_locking_tab_width - upper_inner_locking_tab_depth,overall_height/ 2 - z_carriage_lip_height - part_thickness,0]){
    color("red") cube([upper_inner_locking_tab_depth,part_thickness, switch_offset_from_back - clearance_margin]);
    
  }
}

translate([-1 *(upper_locking_tab_width ),overall_height,0]){
  cube([upper_locking_tab_width + part_thickness,part_thickness, switch_offset_from_back]);
}

locking_tab_tolerance = 0.075;

translate([0,locking_tab_offset_from_bottom,0]){
  linear_extrude(height = part_thickness){
    polygon(points = [
      [0, z_carriage_gap_dim *(6/7)],
      [0,z_carriage_lower_pocket_height],
      [-1 * (z_carriage_wall_thickness + locking_tab_tolerance + lower_clip_margin), z_carriage_lower_pocket_height],
      [-1 * (z_carriage_wall_thickness + locking_tab_tolerance + lower_clip_margin), 0],
      [-1 * (z_carriage_wall_thickness + z_carriage_lower_pocket_width - locking_tab_tolerance), 0],
      [-1 * (z_carriage_wall_thickness + z_carriage_lower_pocket_width - locking_tab_tolerance), z_carriage_lower_pocket_height],
    ]);
  }
}

screw_head_dia = 5.2;
screw_head_height = 3.1;

module bolt_hole_with_pocket(){
  cylinder(r = switch_hole_dia/2, h = switch_offset_from_back *9, $fn=21);
  
  cylinder(r = screw_head_dia/2, h = screw_head_height, $fn=21);
}

interference_margin = 0.19;
early_stop_margin = 2.325;
translate([part_thickness,z_carriage_lip_height + early_stop_margin,0]){
  difference(){
    cube([switch_body_width + switch_roller_width - interference_margin,switch_height,switch_offset_from_back]);
    translate([switch_hole_offset_from_front + switch_roller_width - interference_margin, switch_hole_offset_from_top + switch_hole_dia/2, -1]){
      bolt_hole_with_pocket();
      translate([0,switch_hole_spacing,0]){
        bolt_hole_with_pocket();
      }
    }
    translate([2.5,switch_hole_spacing/2 + switch_hole_dia/2 +switch_hole_offset_from_top,-1]){
      cylinder(r = (switch_hole_spacing/2 + switch_hole_dia/2 +switch_hole_offset_from_top) * (9/12) , h = switch_offset_from_back * 9, $fn = 12);
    }
    
    translate([-1,-1,switch_offset_from_back - clearance_margin]){
      cube([switch_roller_width + 1.5,10, clearance_margin * 2]);
    }
  }
}
