$fn = 21;
motor_dim = 42 + 0.08;

wall_thickness = 1.0;

cutout_margin = 4;

rounding_radius = 1.;
cutout_major_dim = motor_dim - (cutout_margin *4);
cutout_final_dim = cutout_major_dim - rounding_radius * 2;

wall_height = 9;

wire_support_length = 55;
wire_support_width = 17.25 + wall_thickness * 2; 

module plate_cutout(){
  translate([rounding_radius, rounding_radius, 0]){
    minkowski(){
      linear_extrude(height = 20){
        polygon([
        [0,0],
        [0,cutout_final_dim],
        [cutout_final_dim/2 - rounding_radius*2, cutout_final_dim/2 + (cutout_margin/2) ],
        [cutout_final_dim/2 - rounding_radius*2, cutout_final_dim/2 - (cutout_margin/2) ],
        ]);
      };
      cylinder( r = rounding_radius, h =1);
    }
  }
}

wall_cutout_radius = 7;

module wall(cutouts, center_cutouts){
  difference(){
    cube([wall_thickness, motor_dim + wall_thickness, wall_height + wall_thickness]);
    translate([-1, motor_dim/4,wall_height + wall_thickness + wall_cutout_radius * 0.1]){
      rotate([0,90,0]){
        cylinder(r = wall_cutout_radius, h = wall_thickness * 3*cutouts);
      }
    }
     translate([-1, motor_dim*(3/4) + wall_thickness,wall_height + wall_thickness + wall_cutout_radius * 0.1]){
      rotate([0,90,0]){
        cylinder(r = wall_cutout_radius, h = wall_thickness * 3*cutouts);
      }
    }
    translate([-1,motor_dim/2 + wall_thickness, wall_height+ wall_thickness + wall_cutout_radius * 0.05]){
      rotate([0,90,0]){
        cylinder(r = wall_cutout_radius, h = wall_thickness * 3 * center_cutouts);  
      }
    }
  }
}



difference(){  
  cube([motor_dim, motor_dim, wall_thickness]);
  union(){
    translate([0,0,-1]){
      translate([cutout_margin, cutout_margin*2,0]){
        plate_cutout();
      }
      
      
      translate([motor_dim - cutout_margin, cutout_major_dim + cutout_margin*2,0]){
        rotate([0,0,180]){
          plate_cutout();
        }
      }
      
      translate([motor_dim - cutout_margin*2, cutout_margin,0]){
        rotate([0,0,90]){
          plate_cutout();
        }
      }
      
      translate([cutout_margin*2, cutout_major_dim + cutout_margin*3,0]){
        rotate([0,0,270]){
          plate_cutout();
        }
      }
    }
  }
}

translate([-1*wall_thickness,0,0]){
  wall(0, 1);
}


connector_cutout_width = wire_support_width - wall_thickness *2;
translate([0,motor_dim + wall_thickness,0]){
  rotate([0,0,-90]){
    difference(){
      wall(0,0 );
      translate([-0.5,motor_dim/2 - connector_cutout_width/2,wall_thickness]){
        cube([wall_thickness * 3, connector_cutout_width, 20]);
      }
    }
  }
}

translate([motor_dim,-1*wall_thickness,0]){  
  wall(0,1 );  
}

translate([-1*wall_thickness,0,0]){
  rotate([0,0,270]){
    wall(1,0);
  }
}


//strap that goes around motor
strap_width =8;
motor_height = 33.8; 
strap_tab_length = 2;
strap_reinforcement_cyl_radius = 1.3;
module motor_clip(){
  union(){
    cube([strap_width, wall_thickness, motor_height]);
    translate([0,0,motor_height ]){
      color("red") cube([strap_width, wall_thickness+strap_tab_length,wall_thickness]);      
    }
    
    translate([strap_width/2,0.2,-1 * wall_thickness]){
      difference(){
        cylinder(r = strap_reinforcement_cyl_radius, h = motor_height + wall_thickness + wall_thickness);
        translate([-1*strap_width/4,0,0]){
          cube([strap_width/2,5,motor_height + wall_thickness + wall_thickness + 1]);
        }
      }
    }
  }
}

translate([-1*wall_thickness,motor_dim - 2,wall_thickness]){
  rotate([0,0,-90]){
    motor_clip();
  }
}

translate([-1*wall_thickness,strap_width + 2,wall_thickness]){
  rotate([0,0,-90]){
    motor_clip();
  }
}

translate([motor_dim + wall_thickness,motor_dim - strap_width - 2,wall_thickness]){
  rotate([0,0,90]){
    motor_clip();
  }
}

translate([motor_dim + wall_thickness,2 ,wall_thickness]){
  rotate([0,0,90]){
    motor_clip();
  }
}

ziptie_slot_width = 2.4;
ziptie_gap_width = 5;
translate([motor_dim /2 - wire_support_width/2,motor_dim + wall_thickness,0]){
  difference(){
    cube([wire_support_width, wire_support_length, wall_thickness]);
    translate([wire_support_width/2 - ziptie_slot_width - (ziptie_gap_width/2) ,wire_support_length * 0.38,-1]){
      union(){
        minkowski(){
          cube([ziptie_slot_width - 1, wire_support_length * 0.55, wall_thickness*2]);
          cylinder(r = 0.5, h = 1);
        }
      }
    }
    translate([wire_support_width/2  + (ziptie_gap_width/2) ,wire_support_length * 0.38,-1]){
      union(){
        minkowski(){
          cube([ziptie_slot_width - 1, wire_support_length * 0.55, wall_thickness*2]);
          cylinder(r = 0.5, h = 1);
        }
      }
    }
  }
}


translate([motor_dim/2  - wire_support_width/2 + wall_thickness,motor_dim + wall_thickness,wall_thickness]){
  rotate([0,-90,0]){
    linear_extrude(height = wall_thickness){
      polygon([
      [0,0],
      [0,wire_support_length - 1],
      [wall_thickness,wire_support_length - 1],
      [wall_height - 1,0]
      ]);
    }
  }
}

translate([motor_dim/2  + wire_support_width/2 ,motor_dim + wall_thickness,wall_thickness]){
  rotate([0,-90,0]){
    linear_extrude(height = wall_thickness){
      polygon([
      [0,0],
      [0,wire_support_length - 1],
      [wall_thickness,wire_support_length - 1],
      [wall_height - 1,0]
      ]);
    }
  }
}
